#include <Wire.h>  // these libraries are included in the zip file
#include <LiquidCrystal_I2C.h> // and needed to run the code
#include <OneWire.h>
#include <DallasTemperature.h>                                                                                              

#include "floatToString.h"

// If the back of your LCD says 'SainSmart' then you need to use
// address 0x27. So replace the 0x3F with 0x27 below if you have 
// SainSmart on the back of your LCD.
LiquidCrystal_I2C lcd(0x3F, 16, 2);
OneWire oneWire(5);
DallasTemperature sensors(&oneWire);

uint8_t deg[8] = {0x7, 0x5, 0x7, 0x0, 0x0, 0x0, 0x0};
//stores conductivity value
int condVal;

void setup() {
  //Set up pins for LCD and T Probe 
  pinMode(9,OUTPUT);
  pinMode(A2, OUTPUT);
  pinMode(A3,OUTPUT);

  digitalWrite(9,HIGH);
  digitalWrite(A2,LOW);
  digitalWrite(A3,HIGH);
  
  // initialize the LCD
  lcd.begin();
  lcd.backlight();
  lcd.noBlink();
  lcd.noCursor();
  lcd.clear();
  lcd.createChar(0, deg);

  lcd.setCursor(0, 0);

  sensors.begin();
}

void loop() {

  char temp[10];
  char lastTemp[10];

  //get current temperature
  sensors.requestTemperatures();
  floatToString(temp, sensors.getTempCByIndex(0), 2);


  // check if the temp has changed. if not there is no need to update.
  if (strcmp(temp, lastTemp) != 0) {
    //Clear the LCD
    lcd.clear();
    //Print current temperature
    lcd.print("Temp :");
    lcd.print(temp);
    lcd.print(" ");
    lcd.write(0);
    lcd.print("C");


    strcpy(lastTemp, temp);
  }
    condVal = analogRead(A7); // read the analog voltage from cond. probe
  float voltage = condVal*(5.0/1023.0); // assign to val between 0 - 5
  lcd.setCursor(0,1); //set position on LCD
  //Print the relative conductivity
  lcd.print("Rel Cond: ");
  lcd.print(voltage);
  lcd.setCursor(0,0);
  delay(100);

}
